;**********************************************************************
;   This file is a basic code template for assembly code generation   *
;   on the PIC12F508. This file contains the basic code               *
;   building blocks to build upon.                                    *
;                                                                     *
;   Refer to the MPASM User's Guide for additional information on     *
;   features of the assembler (Document DS33014).                     *
;                                                                     *
;   Refer to the respective PIC data sheet for additional             *
;   information on the instruction set.                               *
;                                                                     *
;**********************************************************************
;                                                                     *
;    Filename:	    VIBRATION MONITOR.asm                             *
;    Date:          NOVEMEBER 14 2009                                 *
;    File Version:  1                                                 *
;                                                                     *
;    Author:      R. NEWTON                                           *
;                                                            		  *
;                                                                     * 
;                                                                     *
;**********************************************************************
;                                                                     *
;    Files Required: P12F508.INC                                      *
;                                                                     *
;**********************************************************************
;                                                                     *
;    Notes:                                                           *
;  DETECTS VIBRATIONS AND SOUNDS AN ALARM				              *
;  UNIT ARMS AFTER ONE MINUTE. TO CHANGE TIMING, CHANGE LINE 89
;  TO CHANGE ALARM CHANGE LINE 101 GOTO TO SIREN, TONE, WARBLE	 	  *
;**********************************************************************

	list      p=12F508            ; list directive to define processor
	#include <p12F508.inc>        ; processor specific variable definitions

	__CONFIG   _MCLRE_OFF & _CP_OFF & _WDT_ON & _IntRC_OSC

; '__CONFIG' directive is used to embed configuration word within .asm file.
; The lables following the directive are located in the respective .inc file. 
; See respective data sheet for additional information on configuration word.
;PIN 1		VCC
;PIN 2		GP5 SPEAKERPUT
;PIN 3		GP4
;PIN 4		GP3 MCLR (NOT USED AS MCLR BUT INPUT PIN FOR RESETING
;PIN 5		GP2
;PIN 6		GP1
;PIN 7		GP0 INPUT
;PIN 8		VSS



;***** VARIABLE DEFINITIONS
temp		EQU     0x07        ;example variable definition
COUNTER		EQU		0X08
COUNTER1 	EQU		0X09
COUNTER2	EQU		0AH
LOOP1		EQU		0BH
LOOP2		EQU		0CH
LOOP3		EQU		0DH


#DEFINE		SPEAKER		GPIO,5
#DEFINE		IN			GPIO,0
	

;**********************************************************************
	ORG     0x1FF             ; processor reset vector

; Internal RC calibration value is placed at location 0x1FF by Microchip
; as a movlw k, where the k is a literal value.

	ORG     0x000             ; coding begins here
	movwf   OSCCAL            ; update register with factory cal value 


START		
		BTFSS		STATUS,4		;CHECKING FOR POWER UP
		GOTO		S0				;NOT SET JUMP TO SO
		BTFSS		STATUS,3		;CHECKING FOR POWER UP
		GOTO		S0				;NOT SET JUMP TO SO
		CLRF		COUNTER			;HAS POWERED UP CLEAR COUNTER
S0		MOVLW		B'11001111'		;SETTING FOR MAXIMUM WDT TURN OFF 
		OPTION						;LOAD
		CLRF		GPIO			;CLEAR GPIO
		MOVLW		B'000001'		;MAKE GP0 IN GP4 SPEAKER
		TRIS		GPIO			;LOAD
		BSF			SPEAKER			;TURNING OFF SPEAKER	
		INCF		COUNTER,1		;INCREASE COUNTER
		MOVLW		.026^0FFH		;CHECKING TO SEE IF ABOVE 60 SECONDS
		ADDWF		COUNTER,0		;"
		BTFSC		STATUS,0		;"
		GOTO		S1				;ABOVE 60 SECONDS
		SLEEP						;PUT TO SLEEP
		NOP							;FOR DEBUGGER

S1		MOVLW		B'01001111'		;SETTING FOR MAXIMUM WDT TURN OFF AND ENABLING PIN CHANGE WAKE UP
		OPTION						;LOAD
		MOVF		IN				;READ IN FOR FUTURE DETECTION OF PIN CHANGE 
		BTFSC		STATUS,7		;CHECKING TO SEE IF MOVEMENT HAS OCCURED
		GOTO		SIREN			;MOVEMENT OCCURED JUMP TO ALARM  USE THIS GOTO TO CHANGE SOUNDS
		DECF		COUNTER,1		;KEEP COUNTER FROM COUNTING
		SLEEP						;PUT TO SLEEP
		NOP							;FOR DEBUGGER

;*********************WARBLE SOUND******************
WARBLE
		CLRWDT				;TURN OFF WDT
		MOVLW	.200		;MOVING IN NUMBER
		MOVWF	LOOP1		;LOAD
SA		DECF	LOOP1,1		;DECREMENT LOOP1 RAISING TONE
		MOVLW	.010		;CHECKING TO SEE IF BELOW 10
		SUBWF	LOOP1,0		;CHECKING TO SEE IF BELOW 10
		BTFSC	STATUS,0	;CHECKING TO SEE IF BELOW 10
		GOTO	SA1			;NOT BELOW 10 GOTO SA1
		GOTO	SA2			;BELOW 10 GOTO SA2
SA1		CALL	SB			;PRODUCE TONE
		GOTO	SA			;DO AGAIN
SA2 	INCF	LOOP1,1		;INCREASE LOOP1 LOWERING TONE
		MOVLW	.200^0FFH	;CHECKING TO SEE IF ABOVE 200
		ADDWF	LOOP1,0		;CHECKING TO SEE IF ABOVE 200
		BTFSC	STATUS,0	;CHECKING TO SEE IF ABOVE 200
		GOTO	SA			;ABOVE 200 GOTO SA AND DO ALL OVER
		CALL	SB			;NOT ABOVE 200 PRODUCE TONE
		GOTO	SA2			;DO AGAIN

SB		MOVF	LOOP1,0		;LOADING LOOP1
		MOVWF	LOOP2		;LOADDING LOOP1 INTO LOOP2
		BCF		SPEAKER		;TURN ON SPEAKER
		DECFSZ	LOOP2,1		;CAUSE WABBLE
		GOTO	$-1			;CASUE WABBLE
		MOVF	LOOP1,0		;LOADING LOOP1
		MOVWF	LOOP2		;LOADDING LOOP1 INTO LOOP2
		BSF		SPEAKER		;TURN OFF SPEAKER
		DECFSZ	LOOP2,1		;CAUSING WABBLE
		GOTO	$-1			;CAUSING WABBLE
		RETURN				;RETURN

;******************************EXTRA ALARMS************************

;***********************GENERATING 2,400 KHZ SQUARE WAVE***********************
TONE	CLRWDT				;TURN OFF WDT
		MOVLW	.068		;LOADING NUMBER
		MOVWF	LOOP1		;LOADING NUMBER INTO LOOP1
		BCF		SPEAKER		;TURN ON SPEAKER
		DECFSZ	LOOP1,1		;TURN ON FOR A PERIOD OF TIME
		GOTO	$-1			;TURN ON FOR A PERIOD OF TIME
		MOVLW	.068		;LOADING NUMBER
		MOVWF	LOOP1		;LOADING NUMBER INTO LOOP1
		BSF		SPEAKER		;TURN OFF SPEAKER
		DECFSZ	LOOP1,1		;TURN OFF FOR A PERIOD OF TIME
		GOTO	$-1			;TURN OFF FOR A PERIOD OF TIME
		GOTO	TONE		;KEEP DOING

SIREN
		CLRWDT				;TURN OFF WDT
		MOVLW	.002		;MOVE DECIMAL 2 INTO W
		MOVWF	LOOP3		;LOAD IN LOOP3
SI1		MOVLW	.186		;MOVE DECIMAL 186 INTO W
		MOVWF	LOOP1		;LOAD IN LOOP1
		BCF		SPEAKER		;TURN ON SPEAKER
		DECFSZ	LOOP1,1		;DECREASE LOOP 1 UNTIL ZERO
		GOTO	$-1			;JUMP IF NOT ZERO BACK ONE
		MOVLW	.186		;MOVE DECIMAL 186 INTO W
		MOVWF	LOOP1		;LOAD INTO LOOP1
		BSF		SPEAKER		;TURN OFF SPEAKER
		DECFSZ	LOOP1,1		;DECREASE LOOP 1 UNTIL ZERO
		GOTO	$-1			;JUMP IF NOT ZERO BACK ONE	
		DECFSZ	LOOP2,1		;DECREASE LOOP 2 (256) UNTIL ZERO
		GOTO	SI1			;NOT ZERO GO BACK TO SI1
		DECFSZ	LOOP3,1		;DECREASE LOOP 3 UNTIL ZERO
		GOTO	SI1			;IF NOT ZERO GOTO SI1 (TIME DELAY FOR TONE 1 LOW)
		MOVLW	.004		;MOVE DECIMAL 4 INTO W
		MOVWF	LOOP3		;LOAD IN LOOP 3
SI2		MOVLW	.068		;MOVE DECIMAL 68 INTO W
		MOVWF	LOOP1		;LOAD INTO LOOP 1
		BCF		SPEAKER		;TURN ON SPEAKER
		DECFSZ	LOOP1,1		;DECREASE LOOP 1 UNTIL ZERO 
		GOTO	$-1			;JUMP IF NOT ZERO BACK ONE
		MOVLW	.068		;MOVE DECIMAL 68 INTO W
		MOVWF	LOOP1		;LOAD INTO LOOP 1
		BSF		SPEAKER		;TURN OFF SPEAKER
		DECFSZ	LOOP1,1		;DECREASE LOOP 1 UNTIL ZERO
		GOTO	$-1			;JUMP IF NOT ZERO BACK ONE
		DECFSZ	LOOP2,1		;DECREASE LOOP 2 UNTIL ZERO
		GOTO	SI2			;IF NOT ZERO GOT SI2
		DECFSZ	LOOP3,1		;DECREASE LOOP 3 UNTIL ZERO
		GOTO	SI2			;IF NOT ZERO GOTO SI2 (TIME DELAY FOR TONE 2 HIGH)
		GOTO	SIREN		;KEEP DOING UNTIL POWERED OFF

	END                       ; directive 'end of program'

